==> v0.4.9.zip: libarea/app/Languages/zh_TW/app.php <==
<?php

/*
* The following language strings are used to translate the site core 
* (controllers and templates).
*
* Следующие языковые строки используются для переводя ядра сайта 
* (контроллеры и шаблоны).
*/

return [
    'home'              => '家',
    'catalog'           => '目录',
    'feed'              => '饲料/饲料',
    'test'              => '测试',
    'hi'                => '你好',
    'news'              => '新闻',
    'team'              => '團隊',
    'teams'             => '團隊',
    'owner'             => '所有者',
    'top'               => '最佳',
    'admin'             => '管理面板',
    'well'              => '好的',
    'development'       => '發展',
    'sort'              => '種類',
    'facets'            => '刻面',
    'content'           => '內容',
    'navigation'        => '導航',
    'category'          => '類別',
    'visibility'        => '能見度',
    'number'            => '數字',
    'icon'              => '圖標',
    'icons'             => '图标',
    'template'          => '樣本',
    'setting'           => '環境',
    'settings'          => '設置',
    'security'          => '密碼',
    'avatar'            => '阿凡達',
    'understands'       => '拆解',
    'necessarily'       => '需要填寫',
    'create'            => '寫',
    'writers'           => '作家',
    'by_deposit'        => '按貢獻',
    'welcome'           => '歡迎',
    'create_account'    => '創建一個帳戶',
    'saw'               => '鋸',
    'bodies'            => '身體',
    'thanks'            => '謝謝',
    'whisper'           => '耳語',
    'report'            => '報告',
    'reports'           => '報告',
    'time'              => '時間',
    'deleted'           => '偏僻的',
    'remote'            => '偏僻的',
    'like'              => '像',
    'recommended'       => '推薦的',
    'notification'      => '通知',
    'notifications'     => '通知',
    'preferences'       => '優先',
    'action'            => '行動',
    'domain'            => '領域',
    'domains'           => '域',
    'blog'              => '博客',
    'blogs'             => '博客',
    'topics'            => '話題',
    'topic'             => '話題',
    'parent'            => '家長',
    'authorization'     => '授權',
    'sign_in'           => '登入',
    'sign_out'          => '登出',
    'registration'      => '登記',
    'advertising'       => '廣告',
    'private_messages'  => '私人信息',
    'post_merged'       => '帖子合并',
    'post_appearance'   => '帖子外观',
    'id_merged_post'    => '此帖子将与之合并的帖子的 ID',
    'post_merged_info'  => '这是重要的一步。手动查找 ID，或 0 - 取消合并',
    'it_read'           => '已閱讀',
    'all_messages'      => '所有消息',
    'send_message'      => '對話',
    'dialogues'         => '對話',
    'dialogue'          => '發送消息',
    'write_message'     => '寫信息',
    'send'              => '發送',
    'information'       => '信息',
    'donate'            => '支持项目', 
    'review'            => '審查',
    'contacts'          => '聯繫人',
    'city'              => '城市',
    'remember_me'       => '記住我',
    'banned'            => '禁止',
    'ban_it'            => '禁止',
    'unban'             => '解禁',
    'reset'             => '重啟',
    'invited_guests'    => '受邀',
    'nickname'          => '暱稱',
    'name'              => '姓名',
    'password'          => '密碼',
    'new_password'      => '新密碼',
    'repeat'            => '重複',
    'show'              => '顯示',
    'new'               => '新的',
    'new_ones'          => '新的',
    'old'               => '老的',
    'code'              => '編碼',
    'invite'            => '邀請',
    'invites'           => '邀請',
    'view'              => '看法',
    'views'             => '看法',
    'profile'           => '輪廓',
    'title'             => '姓名',
    'seo_title'         => '标题（用于 SEO）',
    'heading'           => '標題',
    'to_extract'        => '提煉',
    'discussion'        => '討論',
    'description'       => '描述',
    'meta_description'  => '元描述',
    'short_description' => '簡短的介紹',
    'favorites'         => '書籤',
    'long'              => '長',
    'created_by'        => '已創建',
    'help'              => '幫助',
    'statistics'        => '統計數據',
    'privacy'           => '保密',
    'about'             => '關於',
    'about_me'          => '關於我',
    'riddle'            => '神秘',
    'more'              => '更遠',
    'see_more'          => '看更多',
    'read_more'         => '阅读更多',
    'crop_post'         => '作物柱',
    'other'             => '其他',
    'official'          => '官方的',
    'community'         => '社區',
    'trust_level'       => '信任級別',
    'search'            => '搜索',
    'find'              => '尋找',
    'up'                => '向上',
    'user'              => '參與者',
    'users'             => '成員',
    'page'              => '頁',
    'read'              => '讀',
    'reads'             => '阅读',
    'reading'           => '阅读',
    'is_reading'        => '正在阅读',
    'subscribed'        => '簽',
    'unsubscribed'      => '退訂',
    'unsubscribe'       => '退訂',
    'subscribe'         => '訂閱',
    'approved'          => '获批准',
    'remove'            => '刪除',
    'recover'           => '重建',
    'download'          => '下載',
    'password_recovery' => '找回密碼',
    'draft_post'        => '这是草稿帖吗',
    'drafts'            => '草稿',
    'cancel'            => '取消',
    'reply'             => '要回答',
    
    // Редактор
    'foto'              => '照片',
    'bold'              => '脂肪',
    'strikethrough'     => '删除线',
    'italic'            => '斜体',
    'quote'             => '报价',
    'link'              => '连结',
    'preview'           => '预览',
    'toggle_two'        => '两扇窗户',
    'fullscreen'        => '全屏',
    'spoiler'           => '扰流板警报',
    'spoiler_auth'      => '仅适用于授权用户',
    'select_image'      => '请选择图像',
    'drop_image'        => '拖放图像以上传它。',
    'attach_files'      => '可以从缓冲区插入文件',

    'view_policy'       => '只有会员才能看到内容',
    'entry_policy'      => '批准新成员',
    
    'back'              => '返回',
    'edit'              => '要改变',
    'save'              => '储蓄',
    'add'               => '添加',
    'add_post'          => '添加帖子',
    'add_topic'         => '添加主题',
    'add_blog'          => '添加博客',
    'add_category'      => '添加类别',
    'edit_category'     => '更改類別',
    'edit_post'         => '编辑帖子',
    'edit_topic'        => '更改主题',
    'edit_blog'         => '编辑博客',
    'edit_page'         => '编辑页面',
    'edit_section'      => '编辑部分',

    'published'         => '發表於',

    'being_developed'   => '正在开发中',
    'activity'          => '活动',
    'question'          => '问题',
    'questions'         => '问题',
    'question_closed'   => '问题结束了',
    'this_draft'        => '这篇文章，草稿',
    'no_cover'          => '还没有封面',
    'no_invites'        => '您还没有创建任何邀请',
    'no_content'        => '不幸的是，还没有内容',
    'no_dialogs'        => '不幸的是，还没有对话',    
    'no_posts'          => '不幸的是，还没有帖子',
    'no_favorites'      => '不幸的是，还没有书签',
    'no_comments'       => '不幸的是，还没有评论',
    'no_answers'        => '不幸的是，还没有答案',
    'default'           => '默认情况下',
    'qa'                => '问题及答案',
    'answered'          => '回答说',
    'post_translation'  => '帖子是翻译',
    'translation'       => '翻译',
    'format_Q&A'        => '这是一个问题（将成为问答形式）',
    'pin'               => '置顶此帖',
    
    'source'            => '一个来源',
    'website'           => '网站',
    'websites'          => '网站',
    'sites'             => '网站',
    'related'           => '相关',
    'related_posts'     => '相关职位',
    'parents'           => '家长的意见',
    'children'          => '儿童',
    'bound_children'    => '相关(儿童)',
    'bound_parents'     => '相关(家长)',
    'root'              => '根',
    'root_help'         => '顶部（主）树主题',
    'upper'             => '上,上',
    'subtopics'         => '亚科学',
    'badge'             => '酬金',
    'badges'            => '奖项',
    'reward_user'       => '奖励参加者',
    'for_example'       => '例如',
    'ed'                => '教育署',
    'there_are'         => '有',
    'yes'               => '是的',
    'no'                => '非也',
    'all'               => '全部',
    'alls'              => '所有人',
    'you'               => '你',
    'from'              => '从',
    'by'                => '由',
    'in'                => '在',
    'and'               => '和',
    'on'                => '上',
    'for'               => '为',
    'my'                => '我的',
    'publications'      => '刊物及刊物',
    'posted'            => '张贴出来',
    'selected_post'     => '选定职位',
    'color'             => '颜色',
    'text'              => '文本',
    'author'            => '作者',
    'characters'        => '人物',
    'markdown'          => '支援服务 Markdown',
    'write'             => '写',
    'in_profile'        => '在个人资料中',
    'request'           => '请求',
    'results'           => '结果',
    'format_cover_post' => '宽度，500px以上。 方向是水平的',

    'close'             => '关闭它',
    'post_closed'       => '该职位已关闭',
    'repeat_password'   => '重复密码',
    'forgot_password'   => '忘记密码',
    'rules'             => '网站规则',
    'restriction'       => '限制',
    
    'text_closed'       => '未经授权禁止查看此隐藏文本',

    /* Дата и время + события */
    'months'        => ['', '一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月','十月', '十一月', '十二月'],
    'today'         => '今天',
    'yesterday'     => '昨天',

    'num_message'=>['消息','消息','消息'],
    'num_answer'=>['答案','答案','答案'],
    'num_post'=>['后','后','后'],
    'num_view'=>['视图','视图','视图'],
    'num_up'=>['声音','声音','声音'],

    'comment'       => '评论',
    'comments'      => '评论',
    'answer'        => '答案',
    'answers'       => '答案',
    'message'       => '留言',
    'messages'      => '消息',
    'post'          => '后',
    'posts'         => '帖子',

    'language'          => '本地化',
    'ru_language'       => '俄语',
    'ua_language'       => '乌克兰',
    'en_language'       => '英语',
    'de_language'       => '德语',
    'fr_language'       => '法语',
    'zh_TW_language'    => '繁体中文',
    'zh_CN_language'    => '简体中文',
    'ro_language'       => '罗马尼亚语',

    'type'              => '类型',
    'logo'              => '标志',
    'last'              => '最后一次',
    'recommended_size'  => '建议尺寸',

    'you_answered'      => '你已经回答了这个问题',
    'need_login'        => '您需要登录',
    'no_auth'           => '要回答，您可以<a href="/login">登录</a>',
    'auth_comm'         => '你必须登录才能发表评论',
    'not_registered'    => '发布，回复，评论。.. <br>您还没有注册',
    'invalid'           => '无效',
    'agree_rules'       => '继续，即表示您同意<a href="/info/article/privacy">网站使用条款</a>',
    'reg_invite'        => '邀请登记',
    'details_here'      => '详情如下',
    'breaking_rules'    => '违反规则',

    'section'           => '章',
    'tag'               => '标签',
    'tags'              => '标签',
    'folder'            => '文件夹',
    'folders'           => '文件夹',
    'folders_s'         => '文件夹',
    'pages'             => '网页',
    'go_to'             => '过去',
    'seo'               => 'SEO',
    'url'               => 'URL',
    'url_parsing'       => '文章 URL（用于解析）',
    'slug'              => 'SLUG',
    'email'             => 'Email',
    'wiki'              => 'Wiki',
    'edit_answer'       => '让我们改变答案',
    'enter'             => '进入',
    'enter_password'    => '输入密码',

    'rec_posts'         => '推荐职位',
    'rec_posts_desc'    => '手动选择"{name}"中的推荐帖子。 ',
    'topic_subs'        => '订阅主题并在提要中阅读',
    'i_read'            => '我看了',
 
    'message_PM'        => '当消息来到PM',
    'appeal_@'          => '当他们通过电话联系我的时候 @',

    'audits'            => '审计',
    'limits_invitation' => '你的信任程度还不允许你使用邀请',
    'can_send_link'     => '您可以发送此链接',
    'link_used'         => '使用了链接',
    'medal_reg'         => '注册奖章',
    'registered'        => '已登记',
    'invitations_left'  => '没有邀请了',

    'first_days'        => '在社区启动的第一天加入',
    'nickname_replay'   => '这个昵称已经在网站上了',

    'english'           => '英语',
    'post_page'         => '如果填写，帖子将是一个页面（在文档中）',
    'work_email'        => '工作电子邮件（用于<b>帐户激活</b>）<br>工作电子邮件（用于<b>帐户激活</b>）',

    'view_post_tl'      => '谁可以查看帖子（从哪个TL）',
    'invited_you'       => '您是由本网站的参与者邀请的。 输入邀请',
    'invite_features'   => '你可以邀请朋友',

    'content_deleted'   => '{name} 已删除',

    'endless_scroll'        => '在feed中启用滚动？',
    'notification_email'    => '以电邮通知',
    'notifications_limit'   => '最后100个通知显示',

    /* 通知和日志 */
    'notif_add_pm'              => '给你写了一个{url}私信{a}',
    'notif_add_comment'         => '在您的响应{a}上注释{url}',
    'notif_add_comment_comment' => '回复{url}您的评论{a}',
    'notif_add_answer'          => '回复{url}您的帖子{a}',
    'notif_add_flag'            => '收到{url}投诉{a}',
    'notif_add_audit'           => '需要{url}内容审计{a}',
    'notif_references_post'     => '在{url}post{a}中提到过你',
    'notif_references_amswer'   => '在{url}响应{a}中提到你',
    'notif_references_comment'  => '在{url}注释{a}中提到过你',
    'notif_add_website'         => '添加了一个网站{url}查找{a}',
    'notif_edit_website'        => '更改了网站，{url}检查它{a}',
    'notif_approved_website'    => '（主持人）{url}更改（批准）您的网站{a}',
    'notif_add_website_comment' => '{url}在您订阅的网站{a}上发表评论',

];

==> v0.5.0.zip: libarea/app/Languages/zh_TW/app.php <==
<?php

/*
* The following language strings are used to translate the site core 
* (controllers and templates).
*
* Следующие языковые строки используются для переводя ядра сайта 
* (контроллеры и шаблоны).
*/

return [
    'home'              => '家',
    'catalog'           => '目录',
    'feed'              => '饲料/饲料',
    'test'              => '测试',
    'hi'                => '你好',
    'news'              => '新闻',
    'team'              => '團隊',
    'teams'             => '團隊',
    'owner'             => '所有者',
    'top'               => '最佳',
    'admin'             => '管理面板',
    'well'              => '好的',
    'development'       => '發展',
    'sort'              => '種類',
    'facets'            => '刻面',
    'content'           => '內容',
    'navigation'        => '導航',
    'category'          => '類別',
    'visibility'        => '能見度',
    'number'            => '數字',
    'icon'              => '圖標',
    'icons'             => '图标',
    'template'          => '樣本',
    'setting'           => '環境',
    'settings'          => '設置',
    'security'          => '密碼',
    'avatar'            => '阿凡達',
    'understands'       => '拆解',
    'necessarily'       => '需要填寫',
    'create'            => '寫',
    'writers'           => '作家',
    'by_deposit'        => '按貢獻',
    'welcome'           => '歡迎',
    'create_account'    => '創建一個帳戶',
    'saw'               => '鋸',
    'bodies'            => '身體',
    'thanks'            => '謝謝',
    'whisper'           => '耳語',
    'report'            => '報告',
    'reports'           => '報告',
    'time'              => '時間',
    'deleted'           => '偏僻的',
    'remote'            => '偏僻的',
    'like'              => '像',
    'recommended'       => '推薦的',
    'notification'      => '通知',
    'notifications'     => '通知',
    'preferences'       => '優先',
    'action'            => '行動',
    'domain'            => '領域',
    'domains'           => '域',
    'blog'              => '博客',
    'blogs'             => '博客',
    'topics'            => '話題',
    'topic'             => '話題',
    'parent'            => '家長',
    'authorization'     => '授權',
    'sign_in'           => '登入',
    'sign_out'          => '登出',
    'registration'      => '登記',
    'advertising'       => '廣告',
    'private_messages'  => '私人信息',
    'post_merged'       => '帖子合并',
    'post_appearance'   => '帖子外观',
    'id_merged_post'    => '此帖子将与之合并的帖子的 ID',
    'post_merged_info'  => '这是重要的一步。手动查找 ID，或 0 - 取消合并',
    'it_read'           => '已閱讀',
    'all_messages'      => '所有消息',
    'send_message'      => '對話',
    'dialogues'         => '對話',
    'dialogue'          => '發送消息',
    'write_message'     => '寫信息',
    'send'              => '發送',
    'information'       => '信息',
    'donate'            => '支持项目', 
    'review'            => '審查',
    'contacts'          => '聯繫人',
    'city'              => '城市',
    'remember_me'       => '記住我',
    'banned'            => '禁止',
    'ban_it'            => '禁止',
    'unban'             => '解禁',
    'reset'             => '重啟',
    'invited_guests'    => '受邀',
    'nickname'          => '暱稱',
    'name'              => '姓名',
    'password'          => '密碼',
    'new_password'      => '新密碼',
    'repeat'            => '重複',
    'show'              => '顯示',
    'new'               => '新的',
    'new_ones'          => '新的',
    'old'               => '老的',
    'code'              => '編碼',
    'invite'            => '邀請',
    'invites'           => '邀請',
    'view'              => '看法',
    'views'             => '看法',
    'profile'           => '輪廓',
    'title'             => '姓名',
    'seo_title'         => '标题（用于 SEO）',
    'heading'           => '標題',
    'to_extract'        => '提煉',
    'discussion'        => '討論',
    'description'       => '描述',
    'meta_description'  => '元描述',
    'short_description' => '簡短的介紹',
    'favorites'         => '書籤',
    'long'              => '長',
    'created_by'        => '已創建',
    'help'              => '幫助',
    'statistics'        => '統計數據',
    'privacy'           => '保密',
    'about'             => '關於',
    'about_me'          => '關於我',
    'riddle'            => '神秘',
    'more'              => '更遠',
    'see_more'          => '看更多',
    'read_more'         => '阅读更多',
    'crop_post'         => '作物柱',
    'other'             => '其他',
    'official'          => '官方的',
    'community'         => '社區',
    'trust_level'       => '信任級別',
    'search'            => '搜索',
    'find'              => '尋找',
    'up'                => '向上',
    'user'              => '參與者',
    'users'             => '成員',
    'page'              => '頁',
    'read'              => '讀',
    'reads'             => '阅读',
    'reading'           => '阅读',
    'is_reading'        => '正在阅读',
    'subscribed'        => '簽',
    'unsubscribed'      => '退訂',
    'unsubscribe'       => '退訂',
    'subscribe'         => '訂閱',
    'approved'          => '获批准',
    'remove'            => '刪除',
    'recover'           => '重建',
    'download'          => '下載',
    'password_recovery' => '找回密碼',
    'draft_post'        => '这是草稿帖吗?',
    'drafts'            => '草稿',
    'cancel'            => '取消',
    'reply'             => '要回答',
    
    // Редактор
    'foto'              => '照片',
    'bold'              => '脂肪',
    'strikethrough'     => '删除线',
    'italic'            => '斜体',
    'quote'             => '报价',
    'link'              => '连结',
    'preview'           => '预览',
    'toggle_two'        => '两扇窗户',
    'fullscreen'        => '全屏',
    'spoiler'           => '扰流板警报',
    'spoiler_auth'      => '仅适用于授权用户',
    'select_image'      => '请选择图像',
    'drop_image'        => '拖放图像以上传它。',
    'attach_files'      => '可以从缓冲区插入文件',

    'view_policy'       => '只有会员才能看到内容',
    'entry_policy'      => '批准新成员',
    
    'back'              => '返回',
    'edit'              => '要改变',
    'save'              => '储蓄',
    'add'               => '添加',
    'add_post'          => '添加帖子',
    'add_topic'         => '添加主题',
    'add_blog'          => '添加博客',
    'add_category'      => '添加类别',
    'edit_category'     => '更改類別',
    'edit_post'         => '编辑帖子',
    'edit_topic'        => '更改主题',
    'edit_blog'         => '编辑博客',
    'edit_page'         => '编辑页面',
    'edit_section'      => '编辑部分',

    'published'         => '發表於',

    'being_developed'   => '正在开发中',
    'activity'          => '活动',
    'question'          => '问题',
    'questions'         => '问题',
    'question_closed'   => '问题结束了',
    'this_draft'        => '这篇文章，草稿',
    'no_cover'          => '还没有封面',
    'no_invites'        => '您还没有创建任何邀请',
    'no_content'        => '不幸的是，还没有内容',
    'no_dialogs'        => '不幸的是，还没有对话',    
    'no_posts'          => '不幸的是，还没有帖子',
    'no_favorites'      => '不幸的是，还没有书签',
    'no_comments'       => '不幸的是，还没有评论',
    'no_answers'        => '不幸的是，还没有答案',
    'default'           => '默认情况下',
    'qa'                => '问题及答案',
    'best_answer'       => '最佳答案',
    'answered'          => '回答说',
    'post_translation'  => '帖子是翻译?',
    'translation'       => '翻译',
    'format_Q&A'        => '这是一个问题（将成为问答形式）?',
    'pin'               => '置顶此帖?',
    
    'source'            => '一个来源',
    'website'           => '网站',
    'websites'          => '网站',
    'sites'             => '网站',
    'related'           => '相关',
    'related_posts'     => '相关职位',
    'parents'           => '家长的意见',
    'children'          => '儿童',
    'bound_children'    => '相关(儿童)',
    'bound_parents'     => '相关(家长)',
    'root'              => '根',
    'root_help'         => '顶部（主）树主题',
    'upper'             => '上,上',
    'subtopics'         => '亚科学',
    'badge'             => '酬金',
    'badges'            => '奖项',
    'reward_user'       => '奖励参加者',
    'for_example'       => '例如',
    'ed'                => '教育署',
    'there_are'         => '有',
    'yes'               => '是的',
    'no'                => '非也',
    'all'               => '全部',
    'alls'              => '所有人',
    'you'               => '你',
    'from'              => '从',
    'by'                => '由',
    'in'                => '在',
    'and'               => '和',
    'on'                => '上',
    'for'               => '为',
    'my'                => '我的',
    'publications'      => '刊物及刊物',
    'posted'            => '张贴出来',
    'selected_post'     => '选定职位',
    'color'             => '颜色',
    'text'              => '文本',
    'author'            => '作者',
    'characters'        => '人物',
    'markdown'          => '支援服务 Markdown',
    'write'             => '写',
    'in_profile'        => '在个人资料中',
    'request'           => '请求',
    'results'           => '结果',
    'format_cover_post' => '宽度，500px以上。 方向是水平的',

    'close'             => '关闭它',
    'post_closed'       => '该职位已关闭 ?',
    'repeat_password'   => '重复密码',
    'forgot_password'   => '忘记密码',
    'rules'             => '网站规则',
    'restriction'       => '限制',
    
    'text_closed'       => '未经授权禁止查看此隐藏文本',

    /* Дата и время + события */
    'months'        => ['', '一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月','十月', '十一月', '十二月'],
    'today'         => '今天',
    'yesterday'     => '昨天',

    'num_message'=>['消息','消息','消息'],
    'num_answer'=>['答案','答案','答案'],
    'num_post'=>['后','后','后'],
    'num_view'=>['视图','视图','视图'],
    'num_up'=>['声音','声音','声音'],

    'comment'       => '评论',
    'comments'      => '评论',
    'answer'        => '答案',
    'answers'       => '答案',
    'message'       => '留言',
    'messages'      => '消息',
    'post'          => '后',
    'posts'         => '帖子',

    'language'          => '本地化',
    'ru_language'       => '俄语',
    'ua_language'       => '乌克兰',
    'en_language'       => '英语',
    'de_language'       => '德语',
    'fr_language'       => '法语',
    'zh_TW_language'    => '繁体中文',
    'zh_CN_language'    => '简体中文',
    'ro_language'       => '罗马尼亚语',
    'ar_language'       => '阿拉伯',

    'type'              => '类型',
    'logo'              => '标志',
    'last'              => '最后一次',
    'recommended_size'  => '建议尺寸',

    'you_answered'      => '你已经回答了这个问题',
    'need_login'        => '您需要登录',
    'no_auth'           => '要回答，您可以<a href="/login">登录</a>',
    'auth_comm'         => '你必须登录才能发表评论',
    'not_registered'    => '发布，回复，评论。.. <br>您还没有注册',
    'invalid'           => '无效',
    'agree_rules'       => '继续，即表示您同意<a href="/info/article/privacy">网站使用条款</a>',
    'reg_invite'        => '邀请登记',
    'details_here'      => '详情如下',
    'breaking_rules'    => '违反规则',

    'section'           => '章',
    'tag'               => '标签',
    'tags'              => '标签',
    'folder'            => '文件夹',
    'folders'           => '文件夹',
    'folders_s'         => '文件夹',
    'pages'             => '网页',
    'go_to'             => '过去',
    'seo'               => 'SEO',
    'url'               => 'URL',
    'url_parsing'       => '文章 URL（用于解析）',
    'slug'              => 'SLUG',
    'email'             => 'Email',
    'wiki'              => 'Wiki',
    'edit_answer'       => '让我们改变答案',
    'enter'             => '进入',
    'enter_password'    => '输入密码',

    'rec_posts'         => '推荐职位',
    'rec_posts_desc'    => '手动选择"{name}"中的推荐帖子。 ',
    'topic_subs'        => '订阅主题并在提要中阅读',
    'i_read'            => '我看了',
 
    'message_PM'        => '当消息来到PM',
    'appeal_@'          => '当他们通过电话联系我的时候 @',

    'audits'            => '审计',
    'limits_invitation' => '你的信任程度还不允许你使用邀请',
    'can_send_link'     => '您可以发送此链接',
    'link_used'         => '使用了链接',
    'medal_reg'         => '注册奖章',
    'registered'        => '已登记',
    'invitations_left'  => '没有邀请了',

    'first_days'        => '在社区启动的第一天加入',
    'nickname_replay'   => '这个昵称已经在网站上了',

    'english'           => '英语',
    'post_page'         => '如果填写，帖子将是一个页面（在文档中）',
    'work_email'        => '工作电子邮件（用于<b>帐户激活</b>）<br>工作电子邮件（用于<b>帐户激活</b>）',

    'view_post_tl'      => '谁可以查看帖子（从哪个TL）',
    'invited_you'       => '您是由本网站的参与者邀请的。 输入邀请',
    'invite_features'   => '你可以邀请朋友',

    'content_deleted'   => '{name} 已删除',

    'endless_scroll'        => '在feed中启用滚动？',
    'notification_email'    => '以电邮通知',
    'notifications_limit'   => '最后100个通知显示',

    'ignored'               => '忽略',  
    'ignored_users'         => '忽略的用户',
    'ignored_users_help'    => '您不会在提要中看到其帖子的用户。',
    'ignored_no'            => '您没有忽略的用户。', 

    /* 通知和日志 */
    'notif_add_pm'              => '给你写了一个{url}私信{a}',
    'notif_add_comment'         => '在您的响应{a}上注释{url}',
    'notif_add_comment_comment' => '回复{url}您的评论{a}',
    'notif_add_answer'          => '回复{url}您的帖子{a}',
    'notif_add_flag'            => '收到{url}投诉{a}',
    'notif_add_audit'           => '需要{url}内容审计{a}',
    'notif_references_post'     => '在{url}post{a}中提到过你',
    'notif_references_amswer'   => '在{url}响应{a}中提到你',
    'notif_references_comment'  => '在{url}注释{a}中提到过你',
    'notif_add_website'         => '添加了一个网站{url}查找{a}',
    'notif_edit_website'        => '更改了网站，{url}检查它{a}',
    'notif_approved_website'    => '（主持人）{url}更改（批准）您的网站{a}',
    'notif_add_website_comment' => '{url}在您订阅的网站{a}上发表评论',

];
